#!/bin/sh

#############################################
# log delete script
#############################################

## global.cof load
LANG=C;export LANG
SCRIPT_DIR=`dirname $0`
. ${SCRIPT_DIR}/../global.conf

LOG=${SCRIPT_DIR}/log/delete_jobnet_log_`date +%Y%m%d`

#jobnetlog
find ${SCRIPT_DIR}/log -type f -mtime +30 >> ${LOG} 2>&1
find ${SCRIPT_DIR}/log -type f -mtime +30 | xargs rm -f  >> ${LOG} 2>&1

exit 0
