#!/bin/sh

#############################################
# snapshot script
#############################################
LANG=C;export LANG
SCRIPT_DIR=`dirname $0`

## config load
. ${SCRIPT_DIR}/../.root
. ${SCRIPT_DIR}/jobnet_check.conf

SNAP_SHOT=${ROOT}/snapshot/`date +%Y%m%d`

#get snapshot 
SNAP=`ls ${ROOT}/que/tmp | sort -r | sed s/.*:://g | perl -pe 's/\n/\  /g'`
echo "`date +%T` ${SNAP}" >> ${SNAP_SHOT}

exit 0
